import 'dart:async';

import 'package:vgk_game_services/games_services_platform_interface/game_services_platform_interface.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/access_point_location.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/achievement.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/score.dart';

class VgkGameServices {
  static Future<String?> unlock({achievement = Achievement}) async {
    try {
      return await GamesServicesPlatform.instance
          .unlock(achievement: achievement);
    } catch (e) {
      return null;
    }
  }

  static Future<String?> increment({achievement = Achievement}) async {
    try {
      return await GamesServicesPlatform.instance
          .increment(achievement: achievement);
    } catch (e) {
      return null;
    }
  }

  static Future<String?> submitScore({score = Score}) async {
    try {
      return await GamesServicesPlatform.instance.submitScore(score: score);
    } catch (e) {
      return null;
    }
  }

  static Future<String?> showAchievements() async {
    try {
      return await GamesServicesPlatform.instance.showAchievements();
    } catch (e) {
      return null;
    }
  }

  /// It will open the leaderboards screen.
  static Future<String?> showLeaderboards(
      {iOSLeaderboardID = "", androidLeaderboardID = ""}) async {
    try {
      return await GamesServicesPlatform.instance.showLeaderboards(
          iOSLeaderboardID: iOSLeaderboardID,
          androidLeaderboardID: androidLeaderboardID);
    } catch (e) {
      return null;
    }
  }

  static Future<String?> signIn() async {
    try {
      return await GamesServicesPlatform.instance.signIn();
    } catch (e) {
      return null;
    }
  }

  static Future<bool> get isSignedIn async =>
      await GamesServicesPlatform.instance.isSignedIn ?? false;

  static Future<String?> signOut() async {
    try {
      return await GamesServicesPlatform.instance.signOut();
    } catch (e) {
      return null;
    }
  }

  static Future<String?> showAccessPoint(AccessPointLocation location) async {
    try {
      return await GamesServicesPlatform.instance.showAccessPoint(location);
    } catch (e) {
      return null;
    }
  }

  static Future<String?> hideAccessPoint() async {
    try {
      return await GamesServicesPlatform.instance.hideAccessPoint();
    } catch (e) {
      return null;
    }
  }

  static Future<Object?> getPlayer() async {
    try {
      return await GamesServicesPlatform.instance.getPlayer();
    } catch (e) {
      return null;
    }
  }
}
